Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_,
and this project adheres to `Semantic Versioning`_.

`0.1.2`_
--------


Fixed
~~~~~

* Migrations didn't work due to a race condition.


`0.1.1`_
--------

Fixed
~~~~~

* Migrations didn't work due to a race condition.

`0.1`_
------

Added
~~~~~

* Initial release.


.. _Keep a Changelog: https://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning: https://semver.org/spec/v2.0.0.html


.. _0.1: https://edugit.org/katharineum/AlekSIS-App-EvaLU/-/tags/0.1
.. _0.1.1: https://edugit.org/katharineum/AlekSIS-App-EvaLU/-/tags/0.1.1
.. _0.1.2: https://edugit.org/katharineum/AlekSIS-App-EvaLU/-/tags/0.1.2
